==> haskell-vector-builder-0.3.8-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-builder
version:              0.3.8
visibility:           public
id:                   vector-builder-0.3.8-6OccOdj3RovCFKvU3hFCUN
key:                  vector-builder-0.3.8-6OccOdj3RovCFKvU3hFCUN
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/vector-builder
synopsis:             Vector builder
description:
    An API for efficient and convenient construction of vectors.
    It provides the composable `Builder` abstraction, which has instances of the `Monoid` and `Semigroup` classes.

    [Usage]

    First you use the `Builder` abstraction to specify the structure of the vector.
    Then you execute the builder to actually produce the vector.

    [Example]

    The following code shows how you can efficiently concatenate different datastructures into a single immutable vector:

    >
    >import qualified Data.Vector as A
    >import qualified VectorBuilder.Builder as B
    >import qualified VectorBuilder.Vector as C
    >
    >
    >myVector :: A.Vector a -> [a] -> a -> A.Vector a
    >myVector vector list element =
    >  C.build builder
    >  where
    >    builder =
    >      B.vector vector <>
    >      B.foldable list <>
    >      B.singleton element

category:             Vector
abi:                  38a83a98ebbf3da35506d926e2e73b6a
exposed:              True
exposed-modules:
    VectorBuilder.Alternative VectorBuilder.Builder
    VectorBuilder.MVector VectorBuilder.MonadPlus VectorBuilder.Vector

hidden-modules:
    VectorBuilder.Prelude VectorBuilder.Core.Update
    VectorBuilder.Core.Builder

import-dirs:          /usr/lib/ghc-8.10.1/site-local/vector-builder-0.3.8
library-dirs:         /usr/lib/ghc-8.10.1/site-local/vector-builder-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/vector-builder-0.3.8
hs-libraries:         HSvector-builder-0.3.8-6OccOdj3RovCFKvU3hFCUN
depends:
    base-4.14.0.0 base-prelude-1.4-ABZOximOTQnEuKBtBaBHxC
    vector-0.12.1.2-KotqULZza37AeFlfLxbJau

haddock-interfaces:
    /usr/share/doc/haskell-vector-builder/html/vector-builder.haddock

haddock-html:         /usr/share/doc/haskell-vector-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-builder-0.3.8-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-builder
version:              0.3.8
visibility:           public
id:                   vector-builder-0.3.8-1CMznzZOx2q7yJAOYC3nuV
key:                  vector-builder-0.3.8-1CMznzZOx2q7yJAOYC3nuV
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/vector-builder
synopsis:             Vector builder
description:
    An API for efficient and convenient construction of vectors.
    It provides the composable `Builder` abstraction, which has instances of the `Monoid` and `Semigroup` classes.

    [Usage]

    First you use the `Builder` abstraction to specify the structure of the vector.
    Then you execute the builder to actually produce the vector.

    [Example]

    The following code shows how you can efficiently concatenate different datastructures into a single immutable vector:

    >
    >import qualified Data.Vector as A
    >import qualified VectorBuilder.Builder as B
    >import qualified VectorBuilder.Vector as C
    >
    >
    >myVector :: A.Vector a -> [a] -> a -> A.Vector a
    >myVector vector list element =
    >  C.build builder
    >  where
    >    builder =
    >      B.vector vector <>
    >      B.foldable list <>
    >      B.singleton element

category:             Vector
abi:                  56a4921435b31a56709332cde6c5f1e5
exposed:              True
exposed-modules:
    VectorBuilder.Alternative VectorBuilder.Builder
    VectorBuilder.MVector VectorBuilder.MonadPlus VectorBuilder.Vector

hidden-modules:
    VectorBuilder.Prelude VectorBuilder.Core.Update
    VectorBuilder.Core.Builder

import-dirs:          /usr/lib/ghc-8.10.2/site-local/vector-builder-0.3.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/vector-builder-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/vector-builder-0.3.8
hs-libraries:         HSvector-builder-0.3.8-1CMznzZOx2q7yJAOYC3nuV
depends:
    base-4.14.1.0 base-prelude-1.4-HdaTqh6hlYNGbCWV2trBTv
    vector-0.12.1.2-LSJQcQOi3oBDTHyR50MRW6

haddock-interfaces:
    /usr/share/doc/haskell-vector-builder/html/vector-builder.haddock

haddock-html:         /usr/share/doc/haskell-vector-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
